<?php

class Gift_On_User_Registration_Admin_Page {

	public $screen_id;

	public function __construct() {
		add_action( 'admin_menu', array( &$this, 'init_menu' ) );
		add_action( 'current_screen', array( &$this, 'process_form' ) );
	}

	/**
	 * Initializes the admin menu
	 */
	public function init_menu() {
		$this->screen_id = add_options_page( 
			__( 'Gift on Registration', GOUR_LANG_DOMAIN ), 
			__( 'Gift on Registration', GOUR_LANG_DOMAIN ), 
			'manage_options', 
			'gour_page',
			array( &$this, 'display' ) 
		);
	}

	public function display() {
		global $gour_plugin;

		$settings = $gour_plugin->get_settings();

		?>
			<div class="wrap">
				
				<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>

			<?php settings_errors( 'gour_settings' ); ?>
				
				<form action="" method="post" enctype="multipart/form-data" id="gour-form">
					<table class="form-table">
						<tr valign="top">
							<th scope="row">
								<label for="gour_file"><?php _e( 'File', GOUR_LANG_DOMAIN ); ?></label>
							</th>
							<td>
								<input type="file" name="gour_file" id="gour_file"><br/>
								<?php if ( ! empty( $settings['file_dir'] ) ): ?>
									<?php echo '<strong>' . __( 'Current file', GOUR_LANG_DOMAIN ) . '</strong>: ' . $settings['file_dir']; ?>
									<?php submit_button( __( 'Delete file', GOUR_LANG_DOMAIN ), 'secondary', 'remove_file', false ); ?>
								<?php endif; ?>
							</td>
						</tr>
					</table>

					<?php wp_nonce_field( 'upload_gift_file' ); ?>					
					<?php submit_button( __( 'Save changes', GOUR_LANG_DOMAIN ), 'primary', 'upload_gift_file_submit' ); ?>
				</form>
			</div>

		<?php
	}

	/**
	 * Process the form and upload the file
	 */
	public function process_form( $screen ) {
		global $gour_plugin;

		if ( $screen->id == $this->screen_id && isset( $_POST['upload_gift_file_submit'] ) ) {
			check_admin_referer( 'upload_gift_file' );

			if ( ! current_user_can( 'manage_options' ) )
				return false;

			$input = $_POST;

			$settings = $gour_plugin->get_settings();

			if ( ! empty( $_FILES['gour_file']['name'] ) ) {
				$file = $_FILES['gour_file'];

				$gour_plugin->create_uploads_dir();
				$upload_dir = $gour_plugin->get_upload_dir();

				$url = wp_nonce_url( 'options-general.php?page=' . $this->screen_id, 'gour-settings' );
				if ( false === ( $creds = request_filesystem_credentials( $url, '', false, false, null ) ) ) {
					add_settings_error( 'gour_settings', 'file_upload_error', __( 'Error uploading the file', GOUR_LANG_DOMAIN ) );
				}

				$filename = trailingslashit( $upload_dir ) . $file['name'];

				 
				global $wp_filesystem;

				if ( empty( $wp_filesystem ) )
					WP_Filesystem(); 

				$wp_filesystem->delete( $settings['file_dir'] );	

				if ( ! $wp_filesystem->move( $file['tmp_name'], $filename, FS_CHMOD_FILE ) ) {
				   add_settings_error( 'gour_settings', 'file_upload_error', __( 'Error uploading the file', GOUR_LANG_DOMAIN ) );
				}
				else {
					$settings['file_dir'] = $filename;
				}
			}

			delete_option( 'gour_settings' );
			add_option( 'gour_settings', $settings, '', 'no' );

			$errors = get_settings_errors( 'gour_settings' );
			if ( empty( $errors ) ) {
				$updated_url = add_query_arg( 'updated', 'true', $this->get_permalink() );
				wp_redirect( $updated_url );
				exit();
			}

		}

		if ( $screen->id == $this->screen_id && isset( $_POST['remove_file'] ) ) {
			check_admin_referer( 'upload_gift_file' );

			if ( ! current_user_can( 'manage_options' ) )
				return false;

			$settings = $gour_plugin->get_settings();

			global $wp_filesystem;

			if ( empty( $wp_filesystem ) )
				WP_Filesystem(); 

			$wp_filesystem->delete( $settings['file_dir'] );

			$settings['file_dir'] = '';

			delete_option( 'gour_settings' );
			add_option( 'gour_settings', $settings, '', 'no' );

			$errors = get_settings_errors( 'gour_settings' );
			if ( empty( $errors ) ) {
				$updated_url = add_query_arg( 'updated', 'true', $this->get_permalink() );
				wp_redirect( $updated_url );
				exit();
			}
		}
		
	}

	public function get_permalink() {
		return admin_url() . 'options-general.php?page=gour_page';
	}


}