<?php
/*
Plugin Name: Gift on User Registration
Plugin URI: 
Description: Sends a gift (file) to every newly registered user
Version: 1.1
Author: igmoweb
License: GPLv2 
*/

/*  Copyright 2014 Ignacio Cruz Moreno 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


class Gift_On_User_Registration {

	public function __construct() {
		$this->set_globals();
		$this->includes();
		add_action( 'plugins_loaded', array( &$this, 'load_text_domain' ) );
		add_action( 'init', array( &$this, 'init' ) );

		register_activation_hook( __FILE__, array( $this, 'activate' ) );
	}

	public function activate() {
		$this->create_uploads_dir();
	}

	public function create_uploads_dir() {
		$upload_dir = $this->get_upload_dir();
		if ( wp_mkdir_p( $upload_dir ) && ! file_exists( trailingslashit( $upload_dir ) . '.htaccess' ) ) {
			if ( $file_handle = @fopen( trailingslashit( $upload_dir ) . '.htaccess', 'w' ) ) {
				fwrite( $file_handle, 'deny from all' );
				fclose( $file_handle );
			}
		}
	}

	public function get_upload_dir() {
		$upload_dir = wp_upload_dir();
		return $upload_dir['basedir'] . '/gour_files';
	}

	/**
	* Set the plugin constants
	*/
	private function set_globals() {
		// Basics
		define( 'GOUR_VERSION', '0.1' );
		define( 'GOUR_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		define( 'GOUR_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

		// Language domain
		define( 'GOUR_LANG_DOMAIN', 'gour' );
	}

	/**
	* Load the plugin text domain and MO files
	* 
	* These can be uploaded to the main WP Languages folder
	* or the plugin one
	*/
	public function load_text_domain() {
		$locale = apply_filters( 'plugin_locale', get_locale(), GOUR_LANG_DOMAIN );

		load_textdomain( GOUR_LANG_DOMAIN, WP_LANG_DIR . '/' . GOUR_LANG_DOMAIN . '/' . GOUR_LANG_DOMAIN . '-' . $locale . '.mo' );
		load_plugin_textdomain( GOUR_LANG_DOMAIN, false, dirname( plugin_basename( __FILE__ ) ) . '/lang/' );
	}

	/**
	* Includes other files needed
	*/
	public function includes() {
		if ( is_admin() )
			require_once( GOUR_PLUGIN_DIR . 'admin-page.php' );
	}

	/**
	* Initializes the plugin
	*/
	public function init() {
		if ( is_admin() ) {
		  $this->admin_page = new Gift_On_User_Registration_Admin_Page();
		}
		
	}

	public function get_settings() {
		$defaults = array(
		  'file_dir' => ''
		);

		$settings = get_option( 'gour_settings', array() );

		return wp_parse_args( $settings, $defaults );
	}
}

global $gour_plugin;
$gour_plugin = new Gift_On_User_Registration();

if ( ! function_exists( 'wp_new_user_notification' ) ) {
/**
 * Overrides the WP native function
 *
 *
 * @param int $user_id User ID
 * @param string $plaintext_pass Optional. The user's plaintext password
 */
function wp_new_user_notification( $user_id, $plaintext_pass = '' ) {
	global $gour_plugin;

	$user = get_userdata( $user_id );

	// The blogname option is escaped with esc_html on the way into the database in sanitize_option
	// we want to reverse this for the plain text arena of emails.
	$blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

	$message  = sprintf(__('New user registration on your site %s:'), $blogname) . "\r\n\r\n";
	$message .= sprintf(__('Username: %s'), $user->user_login) . "\r\n\r\n";
	$message .= sprintf(__('E-mail: %s'), $user->user_email) . "\r\n";

	@wp_mail(get_option('admin_email'), sprintf(__('[%s] New User Registration'), $blogname), $message);

	if ( empty($plaintext_pass) )
		return;

	$message  = sprintf(__('Username: %s'), $user->user_login) . "\r\n";
	$message .= sprintf(__('Password: %s'), $plaintext_pass) . "\r\n";
	$message .= wp_login_url() . "\r\n";

	$settings = $gour_plugin->get_settings();
	$attachments = is_file( $settings['file_dir'] ) ? array( $settings['file_dir'] ) : array();

	if ( ! empty( $attachments ) )
		$message .= apply_filters( 'gour_email_text', __( 'Thanks for your registration. A gift is attached to this email.', GOUR_LANG_DOMAIN ) );
	
	wp_mail($user->user_email, sprintf(__('[%s] Your username and password'), $blogname), $message, '', $attachments );

}
}
